use super::*;
use std::{
    borrow::Cow,
};

//TODO: Use tokio Watcher instead, to allow hotreloading?
use once_cell::sync::OnceCell;

static INSTANCE: OnceCell<Config> = OnceCell::new();

/// Set the global config instance.
/// This can only be done once for the duration of the program's runtime
pub fn set(conf: Config)
{
    INSTANCE.set(conf).expect("Failed to set global config state: Already set");
}

/// Get the global config instance.
/// `set()` must have been previously called or this function panics.
pub fn get() -> &'static Config
{
    INSTANCE.get().expect("Global config tried to be accessed before it was set")
}

/// Config for this run
#[derive(Debug, Clone, PartialEq, Eq, Hash)]
pub struct Config
{
    /// Name for nanashi
    pub anon_name: Cow<'static, str>,
}

impl Default for Config
{
    #[inline]
    fn default() -> Self
    {
	Self {
	    anon_name: Cow::Borrowed("Nanashi"),
	}
    }
}

